import { CronParser as DefaultParser } from "@/cron";
import { CronExpression, Expression } from "@/common/syntax";
import CronixExpression from "./CronixExpression";
import CronixOptions from "./CronixOptions";
/**
 * Convert an expression to its string representation. If the provided expression is already a string it is simply returned.
 * The conversion strategy depends on the options passed (for instance, Quartz has additional fields which require a different processing).
 * @param expression The expression to convert
 * @param options The context to infer the conversion strategy from
 */
export declare function convertToString(expression: CronixExpression | string, { mode }: CronixOptions): string;
/**
 * A Cron parser with support for multiple cron dialects.
 */
export default class CronixParser {
    private readonly mode;
    private readonly _lexer;
    private readonly _parser;
    private readonly _visitor;
    constructor(options?: CronixOptions);
    /**
     * Parse a complete Cron expression, according to the parser's context.
     * @param expression The expression to parse. Can either be a string or an object describing the expression
     * @return The parsed expression as a syntax tree
     */
    parse<T extends CronExpression>(expression: string | CronixExpression): T;
    /**
     * Parse an expression element, according to the parser's context.
     * @param expression The expression to parse.
     * @return The parsed expression as a syntax tree
     */
    parseField<T extends Expression>(expression: string): T;
    readonly lexer: DefaultParser;
    readonly parser: DefaultParser;
    readonly visitor: import("chevrotain").ICstVisitor<any, any>;
}
